# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from connectors import connector_pb2 as connectors_dot_connector__pb2


class ConnectorServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Dispatcher = channel.unary_unary(
                '/ConnectorService/Dispatcher',
                request_serializer=connectors_dot_connector__pb2.DispatcherRequest.SerializeToString,
                response_deserializer=connectors_dot_connector__pb2.DispatcherResponse.FromString,
                )


class ConnectorServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Dispatcher(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ConnectorServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Dispatcher': grpc.unary_unary_rpc_method_handler(
                    servicer.Dispatcher,
                    request_deserializer=connectors_dot_connector__pb2.DispatcherRequest.FromString,
                    response_serializer=connectors_dot_connector__pb2.DispatcherResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ConnectorService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ConnectorService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Dispatcher(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ConnectorService/Dispatcher',
            connectors_dot_connector__pb2.DispatcherRequest.SerializeToString,
            connectors_dot_connector__pb2.DispatcherResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
