# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: connectors/connector.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x63onnectors/connector.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\"<\n\x11\x44ispatcherRequest\x12\'\n\x07payload\x18\x01 \x01(\x0b\x32\x16.google.protobuf.Value\"A\n\x12\x44ispatcherResponse\x12+\n\x07payload\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.ListValue2K\n\x10\x43onnectorService\x12\x37\n\nDispatcher\x12\x12.DispatcherRequest\x1a\x13.DispatcherResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'connectors.connector_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DISPATCHERREQUEST']._serialized_start=87
  _globals['_DISPATCHERREQUEST']._serialized_end=147
  _globals['_DISPATCHERRESPONSE']._serialized_start=149
  _globals['_DISPATCHERRESPONSE']._serialized_end=214
  _globals['_CONNECTORSERVICE']._serialized_start=216
  _globals['_CONNECTORSERVICE']._serialized_end=291
# @@protoc_insertion_point(module_scope)
